NMSC - New Mexico Appellate Reports

Supreme Court of New Mexico – New Mexico Appellate Reports – 2013
| Sorting options — The authenticated opinions may be sorted by "Filing Date", "Short Title", "Opinion Number", or "Docket No."
| Click on the column name/header — the opinions will sort in descending/ascending order. Note that the Short Title
| column contains the full text of the official final version of an opinion in PDF format.
Filing Date | Short Title | Opinion Number | Docket No.
--- | --- | --- | ---
12/05/2012 | State v. Hall | 2013-NMSC-001 | 32,943
12/06/2012 | Mercer v. Reynolds | 2013-NMSC-002 | 33,830
01/17/2013 | State v. Navarette | 2013-NMSC-003 | 32,898
01/31/2013 | Horne v. Los Alamos Nat'l Sec., L.L.C. | 2013-NMSC-004 | 33,135
01/31/2013 | Martinez v. N.M. Dep't of Transp. | 2013-NMSC-005 | 33,083
02/21/2013 | State Farm Mut. Auto. Ins. Co. v. Safeco Ins. Co. | 2013-NMSC-006 | 33,622
03/14/2013 | In the Matter of Salazar | 2013-NMSC-007 | 33,601
03/14/2013 | In the Matter of Chavez | 2013-NMSC-008 | 33,280
08/24/2012 | ConocoPhillips Co. v. Lyons | 2013-NMSC-009 | 32,624
02/28/2013 | Spencer v. Barber | 2013-NMSC-010 | 33,133
03/25/2013 | Quintana v. Bravo | 2013-NMSC-011 | 33,350
04/08/2013 | State v. Cobrera | 2013-NMSC-012 | 33,375
04/11/2013 | Schultz v. Pojoaque Tribal Police Dep't | 2013-NMSC-013 | 33,372
04/15/2013 | State v. King | 2013-NMSC-014 | 33,395
03/25/2013 | State v. Collier | 2013-NMSC-015 | 32,915
03/28/2013 | State v. Gonzalez | 2013-NMSC-016 | 33,077
04/18/2013 | Sunnyland Farms, Inc. v. Cent. N.M. Elec. Coop., Inc. | 2013-NMSC-017 | 32,968